__version__ = "0.0.15"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = u'(HEAD detached at v0.0.15)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'c61e804ea4f9fd46f0736d6645bc973a72da8839'
__git_head_subject__ = u'Finished Release v0.0.15'
__git_head_message__ = u''
__git_dirty_diff__ = u''